@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -62,32 +62,29 @@ import java.util.HashMap;
 import java.util.Iterator;
 import java.util.List;
 import java.util.Map;
-import java.util.Properties;
 import java.util.Map.Entry;
+import java.util.Properties;
 import java.util.concurrent.ConcurrentHashMap;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
+import org.ho.yaml.Yaml;
 import com.openexchange.config.ConfigurationService;
+import com.openexchange.config.Filter;
 import com.openexchange.config.PropertyListener;
+import com.openexchange.config.WildcardFilter;
 import com.openexchange.config.internal.filewatcher.FileWatcher;
 
 /**
  * {@link ConfigurationImpl}
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public final class ConfigurationImpl implements ConfigurationService {
 
-    private static final Log LOG = LogFactory.getLog(ConfigurationImpl.class);
+    private static final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(ConfigurationImpl.class));
 
     private static final String EXT = ".properties";
 
-    private Map<String, Properties> propertiesByFile = new HashMap<String, Properties>();
-
-    private Map<String, String> texts = new ConcurrentHashMap<String, String>();
-    
-    private final File[] dirs;
-
     private static final class PropertyFileFilter implements FileFilter {
 
         public PropertyFileFilter() {
@@ -100,17 +97,6 @@ public final class ConfigurationImpl implements ConfigurationService {
 
     }
 
-    private final Map<String, String> properties;
-
-    private final Map<String, String> propertiesFiles;
-
-    /**
-     * Initializes a new configuration. The properties directory is determined by system property "<code>openexchange.propdir</code>"
-     */
-    public ConfigurationImpl() {
-        this(getDirectories());
-    }
-
     private static final String[] getDirectories() {
         final List<String> tmp = new ArrayList<String>();
         for (final String property : new String[] { "openexchange.propdir", "openexchange.propdir2" }) {
@@ -122,9 +108,52 @@ public final class ConfigurationImpl implements ConfigurationService {
         return tmp.toArray(new String[tmp.size()]);
     }
 
+    /*-
+     * ------------- Member stuff -------------
+     */
+
+    private final Map<String, String> texts;
+
+    private final File[] dirs;
+
+    /**
+     * Maps file paths of the .properties file to their properties.
+     */
+    private final Map<String, Properties> propertiesByFile;
+
+    /**
+     * Maps property names to their values.
+     */
+    private final Map<String, String> properties;
+
+    /**
+     * Maps property names to the file path of the .properties file containing the property.
+     */
+    private final Map<String, String> propertiesFiles;
+
+    /**
+     * Maps objects to yaml filename, with a path
+     */
+
+     final Map<String, Object> yamlFiles;
+
+    /**
+     * Maps filenames to whole file paths for yaml lookup
+     */
+
+     final Map<String, String> yamlPaths;
+
+
+     /**
+     * Initializes a new configuration. The properties directory is determined by system property "<code>openexchange.propdir</code>"
+     */
+    public ConfigurationImpl() {
+        this(getDirectories());
+    }
+
     /**
      * Initializes a new configuration
-     * 
+     *
      * @param directory The directory where property files are located
      */
     public ConfigurationImpl(final String[] directories) {
@@ -132,43 +161,88 @@ public final class ConfigurationImpl implements ConfigurationService {
         if (null == directories || directories.length == 0) {
             throw new IllegalArgumentException("Missing configuration directory path.");
         }
+        propertiesByFile = new HashMap<String, Properties>();
+        texts = new ConcurrentHashMap<String, String>();
         properties = new HashMap<String, String>();
         propertiesFiles = new HashMap<String, String>();
+        yamlFiles = new HashMap<String, Object>();
+        yamlPaths = new HashMap<String, String>();
+
         final FileFilter fileFilter = new PropertyFileFilter();
         dirs = new File[directories.length];
         for (int i = 0; i < directories.length; i++) {
             if (null == directories[i]) {
                 throw new IllegalArgumentException("Given configuration directory path is null.");
             }
-            dirs[i] = new File(directories[i]);
-            if (!dirs[i].exists()) {
+            final File dir = new File(directories[i]);
+            dirs[i] = dir;
+            if (!dir.exists()) {
                 throw new IllegalArgumentException(MessageFormat.format("Not found: \"{0}\".", directories[i]));
-            } else if (!dirs[i].isDirectory()) {
+            } else if (!dir.isDirectory()) {
                 throw new IllegalArgumentException(MessageFormat.format("Not a directory: {0}", directories[i]));
             }
-            processDirectory(dirs[i], fileFilter, properties, propertiesFiles, propertiesByFile);
+            processDirectory(dir, fileFilter, new FileProcessor() {
+
+                public void processFile(final File file) {
+                    processPropertiesFile(file);
+                }
+
+            });
+
+            processDirectory(dir, new FileFilter() {
+
+                public boolean accept(final File pathname) {
+                    return pathname.isDirectory() || pathname.getName().endsWith(".yml") || pathname.getName().endsWith(".yaml");
+                }
+
+            },
+
+            new FileProcessor() {
+
+                public void processFile(final File file) {
+                    Object o = null;
+                    try {
+                        o = Yaml.load(file);
+                    } catch (final FileNotFoundException e) {
+                        // IGNORE
+                        return;
+                    }
+                    yamlPaths.put(file.getName(), file.getPath());
+                    yamlFiles.put(file.getPath(), o);
+                }
+
+            });
         }
+        
     }
 
-    private static void processDirectory(final File dir, final FileFilter fileFilter, final Map<String, String> properties, final Map<String, String> propertiesFiles, Map<String, Properties> propertiesByFile) {
+    private static interface FileProcessor {
+        public void processFile(File file);
+    }
+
+    private void processDirectory(final File dir, final FileFilter fileFilter, final FileProcessor processor) {
         final File[] files = dir.listFiles(fileFilter);
         if (files == null) {
             LOG.info(MessageFormat.format("Can't read {0}. Skipping.", dir));
             return;
         }
-        for (int i = 0; i < files.length; i++) {
-            if (files[i].isDirectory()) {
-                processDirectory(files[i], fileFilter, properties, propertiesFiles, propertiesByFile);
+        for (final File file : files) {
+            if (file.isDirectory()) {
+                processDirectory(file, fileFilter, processor);
             } else {
-                processPropertiesFile(files[i], properties, propertiesFiles, propertiesByFile);
+                processor.processFile(file);
             }
         }
     }
 
-    private static void processPropertiesFile(final File propFile, final Map<String, String> properties, final Map<String, String> propertiesFiles, Map<String, Properties> propertiesByFile) {
+    void processPropertiesFile(final File propFile) {
         try {
+            if (!propFile.exists() || !propFile.canRead()) {
+                return;
+            }
             final Properties tmp = loadProperties(propFile);
-            propertiesByFile.put(propFile.getPath(), tmp);
+            final String propFilePath = propFile.getPath();
+            propertiesByFile.put(propFilePath, tmp);
             final int size = tmp.size();
             final Iterator<Entry<Object, Object>> iter = tmp.entrySet().iterator();
             for (int i = 0; i < size; i++) {
@@ -177,24 +251,23 @@ public final class ConfigurationImpl implements ConfigurationService {
                 final String otherValue = properties.get(propName);
                 if (properties.containsKey(propName) && otherValue != null && !otherValue.equals(e.getValue())) {
                     final String otherFile = propertiesFiles.get(propName);
-                    if (LOG.isWarnEnabled()) {
-                        final StringBuilder sb = new StringBuilder(64).append("Overwriting property ").append(propName).append(" from file '");
-                        sb.append(otherFile).append("' with property from file '").append(propFile.getPath()).append("', overwriting value '");
+                    if (LOG.isDebugEnabled()) {
+                        final StringBuilder sb =
+                            new StringBuilder(64).append("Overwriting property ").append(propName).append(" from file '");
+                        sb.append(otherFile).append("' with property from file '").append(propFilePath).append("', overwriting value '");
                         sb.append(otherValue).append("' with value '").append(e.getValue()).append("'.");
-                        LOG.warn(sb.toString());
+                        LOG.debug(sb.toString());
                     }
                 }
                 properties.put(propName, e.getValue().toString().trim());
-                propertiesFiles.put(propName, propFile.getPath());
+                propertiesFiles.put(propName, propFilePath);
             }
-        } catch (final FileNotFoundException e) {
-            LOG.error(e.getMessage(), e);
         } catch (final IOException e) {
-            LOG.error(e.getMessage(), e);
+            LOG.warn("An error occurred while processing property file \"" + propFile + "\".", e);
         }
     }
 
-    private static Properties loadProperties(final File propFile) throws FileNotFoundException, IOException {
+    private static Properties loadProperties(final File propFile) throws IOException {
         final FileInputStream fis = new FileInputStream(propFile);
         try {
             final Properties tmp = new Properties();
@@ -209,26 +282,22 @@ public final class ConfigurationImpl implements ConfigurationService {
         }
     }
 
-    /*
-     * (non-Javadoc)
-     * @see com.openexchange.config.Configuration#getProperty(java.lang.String)
-     */
+    public Filter getFilterFromProperty(String name) {
+        final String value = properties.get(name);
+        if (null == value) {
+            return null;
+        }
+        return new WildcardFilter(value);
+    }
+
     public String getProperty(final String name) {
         return properties.get(name);
     }
 
-    /*
-     * (non-Javadoc)
-     * @see com.openexchange.config.Configuration#getProperty(java.lang.String, java.lang.Object)
-     */
     public String getProperty(final String name, final String defaultValue) {
         return properties.containsKey(name) ? properties.get(name) : defaultValue;
     }
 
-    /*
-     * (non-Javadoc)
-     * @see com.openexchange.config.Configuration#getProperty(java.lang.String, com.openexchange.config.PropertyListener)
-     */
     public String getProperty(final String name, final PropertyListener listener) {
         if (properties.containsKey(name)) {
             final PropertyWatcher pw = PropertyWatcher.addPropertyWatcher(name, properties.get(name), true);
@@ -275,27 +344,26 @@ public final class ConfigurationImpl implements ConfigurationService {
      */
     public Properties getFile(final String filename, final PropertyListener listener) {
         String key = null;
-        for (String k : propertiesByFile.keySet()) {
-            if(k.endsWith(filename)) {
+        for (final String k : propertiesByFile.keySet()) {
+            if (k.endsWith(filename)) {
                 key = k;
                 break;
             }
         }
-        
-        if(key == null) {
+
+        if (key == null) {
             return new Properties();
         }
-        
-        Properties tmp = propertiesByFile.get(key);
+
+        final Properties tmp = propertiesByFile.get(key);
         final Properties retval = new Properties();
-        
-        for( Entry<Object, Object> entry : tmp.entrySet()) {
+
+        for (final Entry<Object, Object> entry : tmp.entrySet()) {
             retval.put(entry.getKey(), entry.getValue());
         }
-        
-        
-        if(listener != null) {
-            for(Object k : retval.keySet()) {
+
+        if (listener != null) {
+            for (final Object k : retval.keySet()) {
                 getProperty((String) k, listener);
             }
         }
@@ -311,7 +379,7 @@ public final class ConfigurationImpl implements ConfigurationService {
         final Iterator<Entry<String, String>> iter = propertiesFiles.entrySet().iterator();
         String fldName = folderName;
         for (final File dir : dirs) {
-            fldName = dir.getAbsolutePath() + "/" + fldName + "/";
+            fldName = dir.getAbsolutePath() + File.separatorChar + fldName + File.separatorChar;
             while (iter.hasNext()) {
                 final Entry<String, String> entry = iter.next();
                 if (entry.getValue().startsWith(fldName)) {
@@ -321,7 +389,7 @@ public final class ConfigurationImpl implements ConfigurationService {
                     } else {
                         value = getProperty(entry.getKey(), listener);
                     } // FIXME: this could have been overridden by some property
-                    // external to the requested folder.
+                      // external to the requested folder.
                     retval.put(entry.getKey(), value);
                 }
             }
@@ -375,16 +443,16 @@ public final class ConfigurationImpl implements ConfigurationService {
         return properties.size();
     }
 
-    public String getText(String filename) {
-        String text = texts.get(filename);
-        if(text != null) {
+    public String getText(final String filename) {
+        final String text = texts.get(filename);
+        if (text != null) {
             return text;
         }
-        
-        String[] directories = getDirectories();
-        for (String dir : directories) {
-            String s = traverse(new File(dir), filename);
-            if(s != null) {
+
+        final String[] directories = getDirectories();
+        for (final String dir : directories) {
+            final String s = traverse(new File(dir), filename);
+            if (s != null) {
                 texts.put(filename, s);
                 return s;
             }
@@ -392,39 +460,71 @@ public final class ConfigurationImpl implements ConfigurationService {
         return null;
     }
 
-    private String traverse(File file, String filename) {
-        if(file.getName().equals(filename) && file.isFile()) {
+    private String traverse(final File file, final String filename) {
+        if (file.getName().equals(filename) && file.isFile()) {
             BufferedReader r = null;
             try {
                 r = new BufferedReader(new FileReader(file));
-                StringBuilder builder = new StringBuilder();
+                final StringBuilder builder = new StringBuilder();
                 String s = null;
-                while((s = r.readLine()) != null) {
+                while ((s = r.readLine()) != null) {
                     builder.append(s).append("\n");
                 }
                 return builder.toString();
-            } catch (IOException x) {
-                LOG.fatal("Can't read file: "+file);
+            } catch (final IOException x) {
+                LOG.fatal("Can't read file: " + file);
                 return null;
             } finally {
                 if (r != null) {
                     try {
                         r.close();
-                    } catch (IOException e) {
+                    } catch (final IOException e) {
                         LOG.error(e.getMessage(), e);
                     }
                 }
             }
         }
-        File[] files = file.listFiles();
-        if(files != null) {
-            for (File f : files) {
-                String s = traverse(f, filename);
-                if(s != null) {
+        final File[] files = file.listFiles();
+        if (files != null) {
+            for (final File f : files) {
+                final String s = traverse(f, filename);
+                if (s != null) {
                     return s;
                 }
             }
         }
         return null;
     }
+
+    public Object getYaml(final String filename) {
+        String path = yamlPaths.get(filename);
+        if (path == null) {
+            path = yamlPaths.get(filename+".yml");
+        }
+        if (path == null) {
+            path = yamlPaths.get(filename+".yaml");
+        }
+        if (path == null) {
+            return null;
+        }
+
+        return yamlFiles.get(path);
+    }
+
+
+    public Map<String, Object> getYamlInFolder(final String folderName) {
+        final Map<String, Object> retval = new HashMap<String, Object>();
+        final Iterator<Entry<String, Object>> iter = yamlFiles.entrySet().iterator();
+        String fldName = folderName;
+        for (final File dir : dirs) {
+            fldName = dir.getAbsolutePath() + File.separatorChar + fldName + File.separatorChar;
+            while (iter.hasNext()) {
+                final Entry<String, Object> entry = iter.next();
+                if (entry.getKey().startsWith(fldName)) {
+                    retval.put(entry.getKey(), entry.getValue());
+                }
+            }
+        }
+        return retval;
+    }
 }
