@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -53,7 +53,6 @@ import java.io.File;
 import java.io.FileInputStream;
 import java.io.FileNotFoundException;
 import java.io.IOException;
-import java.util.Iterator;
 import java.util.Map;
 import java.util.Properties;
 import java.util.concurrent.ConcurrentHashMap;
@@ -64,18 +63,18 @@ import com.openexchange.config.internal.filewatcher.FileListener;
 
 /**
  * {@link PropertyWatcher}
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public final class PropertyWatcher implements FileListener {
 
-    private static final org.apache.commons.logging.Log LOG = org.apache.commons.logging.LogFactory.getLog(PropertyWatcher.class);
+    private static final org.apache.commons.logging.Log LOG = com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(PropertyWatcher.class));
 
     private static final ConcurrentMap<String, PropertyWatcher> WATCHER_MAP = new ConcurrentHashMap<String, PropertyWatcher>();
 
     /**
      * Gets an existing property watcher bound to given property name
-     * 
+     *
      * @param name The property name
      * @return The corresponding property watcher or <code>null</code> if none bound to given property name
      */
@@ -85,7 +84,7 @@ public final class PropertyWatcher implements FileListener {
 
     /**
      * Removes an existing property watcher bound to given property name
-     * 
+     *
      * @param name The property name
      */
     public static void removePropertWatcher(final String name) {
@@ -95,7 +94,7 @@ public final class PropertyWatcher implements FileListener {
     /**
      * Adds a new property watcher bound to given property name. If a previous property watcher has already been bound to specified property
      * name, the existing one is returned and no new watcher is created.
-     * 
+     *
      * @param name The property name
      * @param value The property value
      * @param caseInsensitive <code>true</code> to compare changed values case-insensitive; otherwise <code>false</code>
@@ -123,7 +122,7 @@ public final class PropertyWatcher implements FileListener {
 
     /**
      * Initializes a new property watcher
-     * 
+     *
      * @param name The property name to watch
      * @param value The current property value
      * @param caseInsensitive <code>true</code> to compare changed values case-insensitive; otherwise <code>false</code>
@@ -139,7 +138,7 @@ public final class PropertyWatcher implements FileListener {
     /**
      * Adds an instance of {@link PropertyListener} to this watcher's listeners that is going to be notified on property change or delete
      * events.
-     * 
+     *
      * @param listener The listener to add
      */
     public void addPropertyListener(final PropertyListener listener) {
@@ -150,7 +149,7 @@ public final class PropertyWatcher implements FileListener {
 
     /**
      * Removes specified instance of {@link PropertyListener} from this watcher's listeners
-     * 
+     *
      * @param listener The listener to remove
      */
     public void removePropertyListener(final PropertyListener listener) {
@@ -161,7 +160,7 @@ public final class PropertyWatcher implements FileListener {
 
     /**
      * Checks if this property watcher is empty; meaning zero number of added property listeners
-     * 
+     *
      * @return <code>true</code> if this property watcher is empty; otherwise <code>false</code>
      */
     public boolean isEmpty() {
@@ -214,8 +213,8 @@ public final class PropertyWatcher implements FileListener {
 
     private void notifyListeners(final boolean isDelete) {
         final PropertyEvent event = new PropertyEventImpl(name, value, isDelete ? PropertyEvent.Type.DELETED : PropertyEvent.Type.CHANGED);
-        for (final Iterator<PropertyListener> iter = listeners.values().iterator(); iter.hasNext();) {
-            iter.next().onPropertyChange(event);
+        for (final PropertyListener propertyListener : listeners.values()) {
+            propertyListener.onPropertyChange(event);
         }
     }
 
