@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2006 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -49,22 +49,24 @@
 
 package com.openexchange.config.osgi;
 
+import java.util.Hashtable;
 import org.osgi.framework.BundleActivator;
 import org.osgi.framework.BundleContext;
 import org.osgi.framework.ServiceRegistration;
 import com.openexchange.config.ConfigurationService;
+import com.openexchange.config.cascade.ConfigProviderService;
+import com.openexchange.config.internal.ConfigProviderServiceImpl;
 import com.openexchange.config.internal.ConfigurationImpl;
+import com.openexchange.config.internal.filewatcher.FileWatcher;
 
 /**
  * {@link ConfigActivator} - Activator for <code>com.openexchange.config</code> bundle
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public final class ConfigActivator implements BundleActivator {
 
-    private static final org.apache.commons.logging.Log LOG = org.apache.commons.logging.LogFactory.getLog(ConfigActivator.class);
-
-    private ConfigurationService configuration;
+    private static final org.apache.commons.logging.Log LOG = com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(ConfigActivator.class));
 
     private ServiceRegistration registration;
 
@@ -75,32 +77,28 @@ public final class ConfigActivator implements BundleActivator {
         super();
     }
 
-    /*
-     * (non-Javadoc)
-     * @see org.osgi.framework.BundleActivator#start(org.osgi.framework.BundleContext)
-     */
     public void start(final BundleContext context) throws Exception {
         LOG.info("starting bundle: com.openexchange.configread");
-
         try {
-            configuration = new ConfigurationImpl();
-            registration = context.registerService(ConfigurationService.class.getName(), configuration, null);
+            ConfigurationService configService = new ConfigurationImpl();
+            registration = context.registerService(ConfigurationService.class.getName(), configService, null);
+            Hashtable<String, Object> properties = new Hashtable<String,Object>();
+            properties.put("scope", "server");
+            context.registerService(ConfigProviderService.class.getName(), new ConfigProviderServiceImpl(configService), properties);
         } catch (final Throwable t) {
             LOG.error(t.getMessage(), t);
             throw t instanceof Exception ? (Exception) t : new Exception(t);
         }
     }
 
-    /*
-     * (non-Javadoc)
-     * @see org.osgi.framework.BundleActivator#stop(org.osgi.framework.BundleContext)
-     */
     public void stop(final BundleContext context) throws Exception {
         LOG.info("stopping bundle: com.openexchange.configread");
-
         try {
-            registration.unregister();
-            configuration = null;
+            if (null != registration) {
+                registration.unregister();
+                registration = null;
+            }
+            FileWatcher.dropTimer();
         } catch (final Throwable t) {
             LOG.error(t.getMessage(), t);
             throw t instanceof Exception ? (Exception) t : new Exception(t);
